pub struct TorrentFiles {
pub length: usize,
pub path: Vec<String>,
}Expand description
when there is more than one file.
Fields
length: usizesize of the file in bytes
path: Vec<String>a list of strings corresponding to subdirectory names, the last of which is the actual file name
Implementations
Sourceimpl TorrentFiles
impl TorrentFiles
pub fn parse(bencode_tree: &BencodeHashMap) -> Option<TorrentFiles>